@@ -134,7 +134,7 @@ class BaseProvider:
         if isinstance(fields, str):
             fields = [fields, ]
         if fields is None:
-            _, _, others, _ = DatasetD.dataset_info(dataset)
+            _, _, others, _, _ = DatasetD.dataset_info(dataset)
             fields = list(others.keys())
         fields = list(fields)
         return DatasetD.datasets(instruments, fields, start_time, end_time, dataset)
@@ -150,7 +150,7 @@ class BaseProvider:
         if isinstance(fields, str):
             fields = [fields, ]
         if fields is None:
-            _, _, others, _ = DatasetD.dataset_info(dataset)
+            _, _, others, _, _= DatasetD.dataset_info(dataset)
             fields = list(others.keys())
         fields = list(fields)
         return DatasetD.datasets_fl(filt, fields, dataset, **kwargs)
@@ -473,14 +473,14 @@ class DatasetProvider(BaseDataProvider):
         # One process for one task, so that the memory will be freed quicker.
         normalize_column_names = DatasetD.normalize_cache_fields(column_names)
         config_path = fpath + "_config.json"
-        code_flt, time_flt, _, is_annrepo = DatasetD.read_config(config_path)
+        code_flt, time_flt, _, is_annrepo, format_ = DatasetD.read_config(config_path)
         primary_keys = [code_flt, time_flt]            # 插入primary key
         if is_annrepo:
             primary_keys += ["report_period"]
         normalize_column_names = primary_keys + normalize_column_names
         code_flt = ffield(code_flt) if code_flt is not None else None
         time_flt = ffield(time_flt) if time_flt is not None else None
-        dset = ds.dataset(fpath, format="feather")                        # 还差不规则特征
+        dset = ds.dataset(fpath, format=format_)                        # 还差不规则特征
 
         if code_flt is None:
             if time_flt is None:
@@ -509,14 +509,14 @@ class DatasetProvider(BaseDataProvider):
 
         # One process for one task, so that the memory will be freed quicker.
         config_path = fpath + "_config.json"
-        code_flt, time_flt, _, is_annrepo = DatasetD.read_config(config_path)
+        code_flt, time_flt, _, is_annrepo, format_ = DatasetD.read_config(config_path)
         primary_keys = [code_flt, time_flt]            # 插入primary key
         if is_annrepo:
             primary_keys += ["report_period"]
         column_names = primary_keys + column_names
 
         normalize_column_names = DatasetD.normalize_cache_fields(column_names)
-        dset = ds.dataset(fpath, format="feather")
+        dset = ds.dataset(fpath, format=format_)
         # 还差不规则特征
         start = time.perf_counter()
         if filt is None:
@@ -537,7 +537,8 @@ class DatasetProvider(BaseDataProvider):
             time_flt = json_cfg["time_flt"]
             others = json_cfg["others"]
             is_annrepo = json_cfg["is_annrepo"]
-        return code_flt, time_flt, others, is_annrepo
+            format_ = json_cfg.get("format", "feather")
+        return code_flt, time_flt, others, is_annrepo, format_
 
 
 def list_features(freq="*"):
